@@ -299,6 +299,7 @@ schemes = {
             'location': lambda x: x['entry'][0].get('currentLocation'),
             'emails': lambda x: [y['value'] for y in x['entry'][0].get('emails', [])],
             'links': lambda x: [y['url'] for y in x['entry'][0].get('accounts', [])] + [y['value'] for y in x['entry'][0].get('urls', [])],
+            'bio': lambda x: x['entry'][0].get('aboutMe'),
         }
     },
     'Instagram': {
@@ -560,6 +561,12 @@ schemes = {
     },
     '500px GraphQL API': {
         'flags': ['{"data":{"profile":{"id"'],
+        'url_mutations': [
+            {
+                'from': r'https://500px.com/p/(?P<username>.+)/?',
+                'to': 'https://api.500px.com/graphql?operationName=ProfileRendererQuery&variables=%7B%22username%22%3A%22{username}%22%7D&extensions=%7B%22persistedQuery%22%3A%7B%22version%22%3A1%2C%22sha256Hash%22%3A%22105058632482dd2786fd5775745908dc928f537b28e28356b076522757d65c19%22%7D%7D',
+            }
+        ],
         'regex': r'^{"data":({.+})}$',
         'extract_json': True,
         'fields': {
@@ -598,11 +605,32 @@ schemes = {
             'your_ls_uid': lambda x: x.get('docs-offline-lsuid'),
             'your_cpf': lambda x: x.get('docs-cpf'),
             'your_username': lambda x: x.get('docs-offline-ue') or x.get('docs-hue'),
-            'your_uid': lambda x: x['docs-pid'],
+            'viewer_uid': lambda x: x['docs-pid'],
             'org_name': lambda x: x['docs-doddn'],
             'org_domain': lambda x: x['docs-dodn'],
         }
     },
+    'Google Document API': {
+        'flags': ['alternateLink', 'copyRequiresWriterPermission'],
+        'regex': r'^([\s\S]+)$',
+        'extract_json': True,
+        'url_mutations': [
+            {
+                'from': r'https://docs.google.com/(spreadsheets|document|presentation|drawings)/d/(?P<gdoc_id>[\w-]+)',
+                'to': 'https://clients6.google.com/drive/v2beta/files/{gdoc_id}?fields=alternateLink%2CcopyRequiresWriterPermission%2CcreatedDate%2Cdescription%2CdriveId%2CfileSize%2CiconLink%2Cid%2Clabels(starred%2C%20trashed)%2ClastViewedByMeDate%2CmodifiedDate%2Cshared%2CteamDriveId%2CuserPermission(id%2Cname%2CemailAddress%2Cdomain%2Crole%2CadditionalRoles%2CphotoLink%2Ctype%2CwithLink)%2Cpermissions(id%2Cname%2CemailAddress%2Cdomain%2Crole%2CadditionalRoles%2CphotoLink%2Ctype%2CwithLink)%2Cparents(id)%2Ccapabilities(canMoveItemWithinDrive%2CcanMoveItemOutOfDrive%2CcanMoveItemOutOfTeamDrive%2CcanAddChildren%2CcanEdit%2CcanDownload%2CcanComment%2CcanMoveChildrenWithinDrive%2CcanRename%2CcanRemoveChildren%2CcanMoveItemIntoTeamDrive)%2Ckind&supportsTeamDrives=true&enforceSingleParent=true&key=AIzaSyC1eQ1xj69IdTMeii5r7brs3R90eck-m7k',
+                'headers': {"X-Origin": "https://drive.google.com"},
+            }
+        ],
+        'fields': {
+            'created_at': lambda x: x.get('createdDate'),
+            'updated_at': lambda x: x.get('modifiedDate'),
+            'owner_gaia_id': lambda x: x.get('permissions')[1]['id'],
+            'fullname': lambda x: x.get('permissions')[1]['name'],
+            'email': lambda x: x.get('permissions')[1]['emailAddress'],
+            'supposed_username': lambda x: x.get('permissions')[1]['emailAddress'].split('@')[0],
+            'image': lambda x: x.get('permissions')[1]['photoLink'],
+        }
+    },
     'Google Maps contributions': {
         'flags': ['/maps/preview/opensearch.xml', '<meta content="Contributions by'],
         'regex': r'"Contributions by (?P<name>.+?)",("(?P<contributions_count>\d+) Contribution|"(?P<contribution_level>.+?)")',
@@ -731,7 +759,12 @@ schemes = {
     },
     'Stack Overflow & similar': {
         'flags': ['StackExchange.user.init'],
-        'regex': r'StackExchange.user.init\({ userId: (?P<uid>\d+), accountId: (?P<stack_exchange_uid>\d+) }\);',
+        'bs': True,
+        'fields': {
+            'uid': lambda x: x.find('div', {'class': 'avatar'}).find('a').get('href').split('/')[-2],
+            'image': lambda x: x.find('div', {'class': 'avatar'}).find('img').get('src'),
+            'stack_exchange_uid': lambda x: x.find('div', {'id': 'mainbar-full'}).find('a', {'class': 'grid--cell'}).get('href').split('/')[-2],
+        }
     },
     'SoundCloud': {
         'flags': ['eventlogger.soundcloud.com'],
@@ -1091,9 +1124,6 @@ schemes = {
             'bio': lambda x: '\n'.join(x.find('p', {'class': 'authorBlock-header-bio'}).contents),
             'links': lambda x: [a.get('href') for a in x.find('div', {'class': 'authorBlock-meta'}).findAll('a')],
             'joined_year': lambda x: extract_digits(x.find('div', {'class': 'authorBlock-header'}).find('h6').contents[0]),
-            'gravatar_url': lambda x: get_gravatar_url(x.find('div', {'class': 'authorBlock-avatar'}).find('img').get('src', '')),
-            'gravatar_username': lambda x: get_gravatar_username(x.find('div', {'class': 'authorBlock-avatar'}).find('img').get('src', '')),
-            'gravatar_email_hash': lambda x: get_gravatar_email_hash(x.find('div', {'class': 'authorBlock-avatar'}).find('img').get('src', '')),
         }
     },
     'Tproger.ru': {
@@ -1102,9 +1132,6 @@ schemes = {
         'fields': {
             'fullname': lambda x: x.find('div', {'class': 'author-meta'}).find('h2').contents[0],
             'image': lambda x: x.find('div', {'class': 'author-meta'}).find('img').get('data-src', ''),
-            'gravatar_url': lambda x: get_gravatar_url(x.find('div', {'class': 'author-meta'}).find('img').get('data-src', '')),
-            'gravatar_username': lambda x: get_gravatar_username(x.find('div', {'class': 'author-meta'}).find('img').get('data-src', '')),
-            'gravatar_email_hash': lambda x: get_gravatar_email_hash(x.find('div', {'class': 'author-meta'}).find('img').get('data-src', '')),
         }
     },
     'Jsfiddle.net': {
@@ -1115,9 +1142,75 @@ schemes = {
             'company': lambda x: x.find('div', {'class': 'profileDetails'}).find('div', {'class': 'company'}).contents[0].strip(),
             'links': lambda x: [a.get('href') for a in x.find('div', {'class': 'userDetails'}).findAll('a')],
             'image': lambda x: x.find('div', {'class': 'avatar'}).find('img').get('src', ''),
-            'gravatar_url': lambda x: get_gravatar_url(x.find('div', {'class': 'avatar'}).find('img').get('src', '')),
-            'gravatar_username': lambda x: get_gravatar_username(x.find('div', {'class': 'avatar'}).find('img').get('src', '')),
-            'gravatar_email_hash': lambda x: get_gravatar_email_hash(x.find('div', {'class': 'avatar'}).find('img').get('src', '')),
         }
     },
+    'o.yandex.ru': {
+        'flags': ['"cookiesDomain":".o.yandex.ru"'],
+        'regex': r'<script type="application/json" id="initial-state" nonce=".+?">(.+?)<\/script>',
+        'extract_json': True,
+        'fields': {
+            'yandex_public_id': lambda x: x['publicProfile']['params']['publicUserId'],
+            'fullname': lambda x: decode_ya_str(x['publicProfile']['data']['publicProfile']['seller']['name']),
+            'image': lambda x: x['publicProfile']['data']['publicProfile']['seller']['avatar']['size_100x100'],
+            'score': lambda x: x['publicProfile']['data']['publicProfile']['seller']['userBadge']['score'],
+        }
+    },
+    'Disqus API': {
+        'flags': ['https://disqus.com/api/users/'],
+        'regex': r'^([\s\S]+)$',
+        'extract_json': True,
+        'fields': {
+            'id': lambda x: x['response']['id'],
+            'fullname': lambda x: x['response']['name'],
+            'bio': lambda x: x['response']['about'],
+            'reputation': lambda x: x['response']['reputation'],
+            'reputation_label': lambda x: x['response']['reputationLabel'],
+            'following_count': lambda x: x['response']['numFollowers'],
+            'follower_count': lambda x: x['response']['numFollowing'],
+            'location': lambda x: x['response']['location'],
+            'is_power_contributor': lambda x: x['response']['isPowerContributor'],
+            'is_anonymous': lambda x: x['response']['isAnonymous'],
+            'created_at': lambda x: x['response']['joinedAt'],
+            'likes_count': lambda x: x['response']['numLikesReceived'],
+            'url': lambda x: x['response']['url'],
+            'forums_count': lambda x: x['response']['numForumsFollowing'],
+            'image': lambda x: x['response']['avatar']['large']['permalink'],
+        }
+    },
+    'uCoz-like profile page': {
+        'flags': ['UCOZ-JS-DATA'],
+        'bs': True,
+        'fields': {
+            'fullname': lambda x: x.find('div', string='Имя:').next_sibling.split('[')[0].strip(),
+            'url': lambda x: get_ucoz_userlink(x.find('div', string='Пользователь:')),
+            'image': lambda x: get_ucoz_image(x),
+            'gender': lambda x: x.find('div', string='Имя:').next_sibling.split(' ')[-2],
+            'created_at': lambda x: x.find('div', string='Дата регистрации:').next_sibling.strip(),
+            'last_seen_at': lambda x: x.find('div', string='Дата входа:').next_sibling.strip(),
+            'link': lambda x: get_ucoz_uid_node(x).parent.get('href'),
+            'uidme_uguid': lambda x: get_ucoz_uid_node(x).parent.get('href', '').split('/')[-1],
+            'location': lambda x: x.find('div', string='Место проживания:').next_sibling.strip(),
+            'country': lambda x: x.find('div', string='Страна:').next_sibling.strip(),
+            'city': lambda x: x.find('div', string='Город:').next_sibling.strip(),
+            'state': lambda x: x.find('div', string='Штат:').next_sibling.strip(),
+            'email': lambda x: get_ucoz_email(x.find('div', string='E-mail:').next_sibling.strip()),
+            'birthday_at': lambda x: x.find('div', string='Дата рождения:').next_sibling.split('[')[0].strip(),
+        },
+    },
+    'uID.me': {
+        'flags': [' - uID.me</title>'],
+        'bs': True,
+        'fields': {
+            'username': lambda x: x.find('title').contents[0].split(' ')[0],
+            'image': lambda x: 'https://uid.me' + x.find('img', {'id': 'profile_picture'}).get('src'),
+            'headline': lambda x: x.find('h2', {'id': 'profile_headline'}).contents[0].strip(),
+            'bio': lambda x: x.find('div', {'id': 'profile_bio'}).contents[0].strip(),
+            'contacts': lambda x: [a.contents[0] for a in x.find('div', {'id': 'profile_contacts'}).find_all('a')],
+            'email': lambda x: x.find('a', {'id': 'user-email'}).contents[0],
+            'phone': lambda x: x.find('span', {'id': 'profile-phone'}).contents[0],
+            'skype': lambda x: x.find('span', {'id': 'profile-skype'}).contents[0],
+            'location': lambda x: ','.join([a.contents[0] for a in x.find('ul', {'id': 'profile_places'}).find_all('a')]),
+            'links': lambda x: [a.get('href') for a in x.find('div', {'id': 'list_my-sites'}).find_all('a')] or None,
+        },
+    },
 }
